@@ -6,19 +6,24 @@ that are 3 letters or fewer. Thus, the standard metasyntactic variables in
 these tests have been amended to 'fooo' and 'baar'. Ho hum.
 """
 
-import os
+from __future__ import unicode_literals
+
+import os, json
 from unittest import skipUnless
 
 from django.db import models
 from django.test import TestCase
 from django.core.management import call_command
-from django.conf.urls.defaults import *
+try:
+    from django.conf.urls import *
+except ImportError:  # Django<1.4
+    from django.conf.urls.defaults import *
 from django.conf import settings
 from django.contrib import admin
 from django.contrib.auth.models import User
 from django.http import HttpResponseNotFound, HttpResponseServerError
 from django import template
-from django.utils import simplejson as json
+from django.utils.encoding import force_text
 
 import watson
 from watson.registration import RegistrationError, get_backend, SearchEngine
@@ -440,14 +445,14 @@ class RankingTest(SearchTestBase):
     def testRankingWithSearch(self):
         self.assertEqual(
             [entry.title for entry in watson.search("FOOO")],
-            [u"title model1 instance11 fooo baar fooo", u"title model1 instance12"]
+            ["title model1 instance11 fooo baar fooo", "title model1 instance12"]
         )
             
     @skipUnless(get_backend().supports_ranking, "search backend does not support ranking")
     def testRankingWithFilter(self):
         self.assertEqual(
             [entry.title for entry in watson.filter(WatsonTestModel1, "FOOO")],
-            [u"title model1 instance11 fooo baar fooo", u"title model1 instance12"]
+            ["title model1 instance11 fooo baar fooo", "title model1 instance12"]
         )
 
 
@@ -599,7 +604,7 @@ class SiteSearchTest(SearchTestBase):
         # Test a search that should find everything.
         response = self.client.get("/simple/json/?q=title")
         self.assertEqual(response["Content-Type"], "application/json; charset=utf-8")
-        results = set(result["title"] for result in json.loads(response.content)["results"])
+        results = set(result["title"] for result in json.loads(force_text(response.content))["results"])
         self.assertEqual(len(results), 4)
         self.assertTrue("title model1 instance11" in results)
         self.assertTrue("title model1 instance12" in results)
@@ -642,7 +647,7 @@ class SiteSearchTest(SearchTestBase):
         # Test a search that should find everything.
         response = self.client.get("/custom/json/?fooo=title&page=last")
         self.assertEqual(response["Content-Type"], "application/json; charset=utf-8")
-        results = set(result["title"] for result in json.loads(response.content)["results"])
+        results = set(result["title"] for result in json.loads(force_text(response.content))["results"])
         self.assertEqual(len(results), 4)
         self.assertTrue("title model1 instance11" in results)
         self.assertTrue("title model1 instance12" in results)
@@ -654,4 +659,4 @@ class SiteSearchTest(SearchTestBase):
         
     def tearDown(self):
         super(SiteSearchTest, self).tearDown()
-        settings.TEMPLATE_DIRS = self.old_TEMPLATE_DIRS
\ No newline at end of file
+        settings.TEMPLATE_DIRS = self.old_TEMPLATE_DIRS
