@@ -1,6 +1,11 @@
 """URLs for the built-in site search functionality."""
 
-from django.conf.urls.defaults import *
+from __future__ import unicode_literals
+
+try:
+    from django.conf.urls import *
+except ImportError:  # Django<1.4
+    from django.conf.urls.defaults import *
 
 
 urlpatterns = patterns("watson.views",
@@ -9,4 +14,4 @@ urlpatterns = patterns("watson.views",
     
     url("^json/$", "search_json", name="search_json"),
 
-)
\ No newline at end of file
+)
